@@ -217,11 +217,9 @@ public class NoteCoords implements MeasureComponent {
 
                 if(noteForTie.getLastFromY() != fromY){
                     gc.drawString("L", x, y - 7); 
-                }else{
-                    int noteForTieFomrX = noteForTie.getLastFromX();
-                    int noteForTieFomrY = noteForTie.getLastFromY();                    
-                    int ligadureX = noteForTie.getPosX() + noteForTieFomrX + this.meassureCoords.getSpanForComponent(noteForTie);
-                    int ligadureY = noteForTie.getPosY() + noteForTieFomrY + 10;
+                }else{              
+                    int ligadureX = noteForTie.getPointX();
+                    int ligadureY = noteForTie.getLastFromY() + noteForTie.getPosY() + 10;
                     gc.drawArc(ligadureX, ligadureY, (x - ligadureX), -30, 225, 90);
                 }
             }
